Value Types
===========

Value Types are extended datatype objects for columsn in a row generators. Value types allow
columns to be described as holding dates, geographic regions, census region identifiers,
or any other complex object, which alows for sophisticated manipulations in transforms.